#
# spec file for package esound
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           esound
BuildRequires:  alsa-devel
BuildRequires:  audiofile-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  tcpd-devel
Summary:        A sound daemon for Enlightenment and GNOME
License:        LGPL-2.0+
Group:          System/Sound Daemons
Version:        0.2.41
Release:        30.5
Url:            ftp://ftp.gnome.org/pub/gnome/sources/esound/
Source:         ftp://ftp.gnome.org/pub/gnome/sources/esound/0.2/%{name}-%{version}.tar.bz2
Source1:        esound.init
Source2:        sysconfig.esound
Source3:        baselibs.conf
Patch0:         esd-as.patch
# PATCH-FIX-UPSTREAM esound-biarch.patch bgo545534 sbrabec@suse.cz -- fix bi-arch clash
Patch1:         esound-biarch.patch
# PATCH-FIX-UPSTREAM esound-esddsp-no-version-info.patch bgo545534 sbrabec@suse.cz -- move non-standard library to a separate directory
Patch5:         esound-esddsp-no-version-info.patch
Patch6:         esound-0.2.41-no_dev_random.patch
Patch7:         esound-link-libm.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define debug_package_requires libesd0 = %{version}

%description
A multiplexing and caching sound daemon. It can use ALSA or OSS for
sound output. Many projects, including Enlightenment and GNOME, use
esound to play and record their sounds.

%package -n libesd0
Summary:        A sound daemon for Enlightenment and GNOME
Group:          System/Libraries
Recommends:     %{name}-daemon >= %{version}
# bug437293
%ifarch ppc64
Obsoletes:      esound-64bit
%endif
#

%description -n libesd0
A multiplexing and caching sound daemon. It can use ALSA or OSS for
sound output. Many projects, including Enlightenment and GNOME, use
esound to play and record their sounds.

%package daemon
Summary:        A sound daemon for Enlightenment and GNOME
Group:          System/Sound Daemons
PreReq:         %insserv_prereq %fillup_prereq
Obsoletes:      esound < %{version}
# For update from <= 11.0 and SLE <= 10
Provides:       esound:%{_bindir}/esd
# we put the conflict in here as they both provide the same
# and the solver may pick both. p-e-c can not conflict with
# esound-daemon as it also provides it
Conflicts:      pulseaudio-esound-compat

%description daemon
A multiplexing and caching sound daemon. It can use ALSA or OSS for
sound output. Many projects, including Enlightenment and GNOME, use
esound to play and record their sounds.

%package utils
Summary:        A sound daemon for Enlightenment and GNOME
Group:          Productivity/Multimedia/Sound/Utilities
# For update from <= 11.0 and SLE <= 10
Provides:       esound:%{_bindir}/esddsp

%description utils
A multiplexing and caching sound daemon. It can use ALSA or OSS for
sound output. Many projects, including Enlightenment and GNOME, use
esound to play and record their sounds.

%package -n libesd-devel
Summary:        EsounD development package
Group:          Development/Libraries/C and C++
# replaces esound-devel, which existed for <= 11.0 and <= SLED10
Provides:       esound-devel = %{version}
Obsoletes:      esound-devel < %{version}
Requires:       libesd0 = %{version} alsa-devel %(rpm -q --queryformat '%{NAME}' -f %{_libdir}/pkgconfig/audiofile.pc)

%description -n libesd-devel
EsounD development package.

%prep
%setup -q
%patch0
%patch1
%patch5 -p1
%patch6
%patch7 -p1

%build
autoreconf -f -i
export CFLAGS="%{optflags} -fno-strict-aliasing"

%configure\
	--disable-static\
	--with-libwrap\
	--enable-ipv6
make %{?_smp_mflags}

%install
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/init.d
cp %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/init.d/esound
chmod +x $RPM_BUILD_ROOT%{_sysconfdir}/init.d/esound
mkdir -p $RPM_BUILD_ROOT%{_sbindir}
ln -s ../..%{_sysconfdir}/init.d/esound $RPM_BUILD_ROOT%{_sbindir}/rcesound
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/adm/fillup-templates
cp %{SOURCE2} $RPM_BUILD_ROOT%{_localstatedir}/adm/fillup-templates/
rm $RPM_BUILD_ROOT%{_libdir}/%{name}/*.*a

%post -n libesd0 -p /sbin/ldconfig

%postun -n libesd0 -p /sbin/ldconfig

%post daemon
%{fillup_and_insserv}

%postun daemon
%{insserv_cleanup}

%preun daemon
%{stop_on_removal}

%files -n libesd0
%defattr(-, root, root)
%{_libdir}/*.so.*

%files daemon
%defattr(-, root, root)
%doc README AUTHORS COPYING.LIB NEWS TODO TIPS MAINTAINERS
%{_bindir}/esd
%{_localstatedir}/adm/fillup-templates/*
%doc %{_mandir}/man1/esd.*
%{_sbindir}/*
%config %{_sysconfdir}/esd.conf
%{_sysconfdir}/init.d/*

%files utils
%defattr(-, root, root)
%{_bindir}/esd[a-z]*
%doc %{_mandir}/man1/esd[a-z]*.*
%{_libdir}/%{name}

%files -n libesd-devel
%defattr(-, root, root)
%{_bindir}/esd-config
%{_datadir}/aclocal/*
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/*.*a
%{_libdir}/pkgconfig/esound.pc
%doc %{_mandir}/man1/esd-config.*

%changelog
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Wed Sep 28 2011 dimstar@opensuse.org
- Add esound-link-libm.patch: Link esd against libm to fix build on
  Factory.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Sat May 22 2010 cristian.rodriguez@opensuse.org
- read /dev/urandom and not /dev/random
- build with fno-strict-aliasing
* Thu Dec 17 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Mon Sep  7 2009 coolo@novell.com
- do not let esound and pulseaudio be installed together
* Fri Mar 20 2009 dmueller@suse.de
- downgrade runtime requirement to recommends for libesd0
* Mon Feb  9 2009 rodrigo@novell.com
- Update to 0.2.41, which contains several fixes for interacting
  with PulseAudio (bnc#460760)
  + http://ftp.gnome.org/pub/GNOME/sources/esound/0.2/esound-0.2.41.news
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Sep 17 2008 sbrabec@suse.cz
- Fixed Provides and Obsoletes (bnc#364819).
* Wed Aug  6 2008 mauro@suse.de
- Update to version 0.2.39
  * Fixed esd client-side code to not hang if esd crashes/hangs
    or otherwise becomes unreachable (Jeffrey Stedfast)
  * Suppress verbose error messages from ALSA (Stanislav Brabec)
  * Allow for multiple esd instances
  * Fix esound-config for multi-lib setups (Matthias Clasen)
  * Don't report errors about /dev/dsp not existing (Havoc Pennington)
  * Various other build fixes for AMD64 (Rémi Cardona)
- Dropped esound-suppress-alsa-debug.diff, it's already present in
  upstream version.
- Dropped esound-multi-user-375701.patch, it's already present in
  upstream version.
- Dropped esound-configure.patch, it's already present in the
  upstream version.
- Updated esound-esddsp-no-version-info.patch to the current
  upstream code.
* Sun Aug  3 2008 ro@suse.de
- fix requires for debuginfo package
* Wed Jul 30 2008 sbrabec@suse.cz
- Fixed package splitting (bnc#412459).
- Splitted esound to esound-daemon and esound-utils.
- Improved packaging of esddsp (bgo#545534).
* Wed Jun 18 2008 schwab@suse.de
- Fix configure script.
* Mon May 12 2008 rodrigo@suse.de
- Added esound-multi-user-375701.patch from Fedora to make libesd
  work correctly with multiple users (bnc#375701)
* Wed May  7 2008 coolo@suse.de
- Fix last change. Now it really works - granted
* Mon May  5 2008 aj@suse.de
- One more fix for baselibs.conf
- Fix rpmlint warnings:
  * Use $portmap for init script
  * Add missing requires for packages
* Fri May  2 2008 aj@suse.de
- Fix last change.
* Tue Apr 29 2008 cthiel@suse.de
- obsolete esound-<arch> via baselibs.conf
* Fri Apr 18 2008 sbrabec@suse.cz
- Suppress verbose error messages from alsa-lib (bnc#300031,
  bgo#528718).
- Updated init script.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Jan 10 2008 maw@suse.de
- Rename esound-devel to libesd-devel.
* Thu Dec 13 2007 maw@suse.de
- s#%%run_ldconfig#/sbin/ldconfig# in %%post and %%postun
- Add a %%preun with %%stop_on_removal
- Don't package INSTALL
- Split out a libesd0 subpackage (#267194).
* Thu Jul  5 2007 maw@suse.de
- Update to version 0.2.38, which makes the following line
  necessary:
- Remove upstreamed esound-cpu-load.patch and abuild.patch.
* Wed Apr 18 2007 sbrabec@suse.cz
- Fixed 100%% CPU load (#264637, GNOME #412951, Joe Marcus Clarke).
- Removed upstreamed esound-close-fds.patch.
* Wed Mar 21 2007 maw@suse.de
- Add abuild.patch, silencing a gcc warning.
* Wed Mar 21 2007 maw@suse.de
- Update to version 0.2.37
- Fixes bugzilla.gnome.org #350808
- Removes upstreamed esound-logout-sound-167856.patch
- Buildrequire pkg-config.
* Fri Jan 19 2007 sbrabec@suse.cz
- Moved libesd.so back to the devel package, new flash player does
  not need it (#212515).
- Spec file cleanup.
* Fri Oct 27 2006 sbrabec@suse.cz
- Moved libesd.so to the main package, as required by
  flash-player (#212515).
* Thu Aug 17 2006 aj@suse.de
- Reduce BuildRequires to not depend on TeX.
* Tue May 23 2006 joeshaw@suse.de
- Add a patch to fix the GNOME logout sound being cut off.
  (bnc #167856)
* Thu Mar  2 2006 danw@suse.de
- close unneeded file descriptors at daemon startup (since it may
  have been spawned from a random app with random things open). #154072
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 sbrabec@suse.cz
- Bi-arch preloader fix of esddsp (#140505).
* Tue Jun 21 2005 sbrabec@suse.cz
- Updated to version 0.2.36.
- Support for tcp_wrappers and IPv6.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Tue Apr 12 2005 ro@suse.de
- added audiofile-devel to neededforbuild
* Thu Jan 27 2005 tiwai@suse.de
- fixed the sound playback with dmix plugin.
* Fri Dec  3 2004 sbrabec@suse.cz
- Fixed sound device blocking, if spawned esd caches samples - use -as
  twice in esd.conf, weaken requirements for -terminate (#45741).
* Fri Oct  1 2004 sbrabec@suse.cz
- Free audio device by default (#46507).
* Tue Aug 24 2004 sbrabec@suse.cz
- Updated to version 0.2.35.
* Wed Mar  3 2004 sbrabec@suse.cz
- Updated to version 0.2.33.
* Fri Jan 16 2004 pth@suse.de
- Fix quoting in esd.m4
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Tue Sep  9 2003 sbrabec@suse.cz
- Updated to version 0.2.32.
* Fri Aug 29 2003 sbrabec@suse.cz
- Check -terminate in persistent daemon mode.
* Wed Aug 13 2003 sbrabec@suse.cz
- Updated to version 0.2.31.
* Mon Aug  4 2003 sbrabec@suse.cz
- Updated to version 0.2.30.
* Thu Jun 12 2003 kukuk@suse.de
- Correct filelist
* Mon Jun  2 2003 sbrabec@suse.cz
- Added init script for network sound server.
* Thu May 15 2003 sbrabec@suse.cz
- Typo fix (NBSP characters).
* Thu May 15 2003 sbrabec@suse.cz
- Require alsa-devel for esound-devel.
* Sun May 11 2003 ro@suse.de
- do full autoreconf (run libtool)
* Mon Feb 24 2003 sbrabec@suse.cz
- Updated esd man page.
* Fri Nov 29 2002 sbrabec@suse.cz
- Added esound ALSA fix (from Takashi Iwai, closes #22163).
* Fri Nov 29 2002 sbrabec@suse.cz
- Use OSS instead of ALSA, until bug #22163 gets solved.
* Thu Oct 24 2002 hhetter@suse.de
- invoke automake with -c to ensure file copying
  (Bug Id #21066)
* Mon Oct 14 2002 sbrabec@suse.cz
- Update to version 0.2.29. Removed esd-alsa-dev.dif - similar fix is now
  part of code.
- Added manual pages to %%files.
* Fri Sep 20 2002 tiwai@suse.de
- added alsa-devel to neededforbuild.
- fixed alsa output to reflect the change via -d option.
* Tue Sep 17 2002 sbrabec@suse.cz
- Added alsa to neededforbuild. Esound now uses ALSA.
* Mon Aug 26 2002 nadvornik@suse.cz
- fixed permissions of doc files
* Thu Jun 20 2002 jordi@suse.de
- updated to version 0.2.28
* Mon Jun 17 2002 ro@suse.de
- call automake with "-a -f"
* Tue Jun 11 2002 hhetter@suse.de
- updated to version 0.2.27
* Tue Jun  4 2002 hhetter@suse.de
- updated to version 0.2.26
* Fri May 31 2002 adrian@suse.de
- fix build for ppc64
* Fri Apr 26 2002 coolo@suse.de
- %%_libdir support
* Wed Jan  9 2002 hhetter@suse.de
- updated to version 0.2.23
  * pkgconfig file for GNOME 2.0 compatibility
- adapted ia64 include file fix
* Fri May 25 2001 nadvornik@suse.cz
- fixed include files for ia64
* Mon Dec 25 2000 egger@suse.de
- Cleaned up specfile.
- Changed group of development package.
- Recompressed sources with bzip2.
* Sat Dec  9 2000 egger@suse.de
- Updated to version 0.2.22.
* Mon Nov  6 2000 tiwai@suse.de
- Split esound-devel package.
* Wed Nov  1 2000 egger@suse.de
- Updated specfile to new long packagenames.
- Reworked specfile.
- Probably needs some more work; I'm taking care of that.
* Fri Sep 29 2000 hhetter@suse.de
- added security patch
* Wed Sep  6 2000 egger@suse.de
- Updated to version 0.2.19.
* Fri Sep  1 2000 tiwai@suse.de
- fixed the bug of 0.2.18 (playing too short without synchronized).
* Fri May 26 2000 ke@suse.de
- update to version 0.2.18.
- add html docs.
* Thu May 11 2000 ke@suse.de
- Improve files list to catch missing shared libs (don't trust wildcards
  too much; you'll never know).
* Fri Apr  7 2000 bk@suse.de
- added suse update config macro
* Thu Mar 30 2000 cihlar@suse.cz
- update to version 2.17
- clean up spec file
* Tue Dec 14 1999 ro@suse.de
- fixed install (broke with BuildRoot)
* Fri Nov  5 1999 ke@suse.de
- Update to version 0.2.16 (security fixes and more).
- Use BuildRoot.
- Use RPM_OPT_FLAGS (instead of RPM_OPT_FLAG ...)
- Correct Copyright.
- Add "Group:" entry.
* Mon Oct 25 1999 kukuk@suse.de
- Update to version 0.2.15
* Fri Sep 17 1999 kettner@suse.de
- Reinserted old # Commandline: line.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue May  4 1999 mb@suse.de
- updated to new version 0.2.8
* Fri Feb 19 1999 mb@suse.de
- fixed lib problems
* Tue Feb 16 1999 mb@suse.de
- new version 0.2.7 needed for enlightenment, gnome and emusic
* Sat Jul 18 1998 mb@suse.de
- first inital version 0.2 of the esound (Enlightenment sound daemon)
